import pandas as pd
import numpy as np


def mock_big_array():

    # mock a facts table
    f = np.array([
        [1, 1000],
        [2, 5222],
        [3, 20000],
        [4, 66666],
        [5, 888888],
        [6, 777777],
        [7, 333333],
        [8, 1111111]
    ])

    # mock a dimension
    d = np.array([
        [1, 'data1', 'data8'],
        [2, 'data4', 'data9'],
        [3, 'data3', 'data9'],
        [4, 'data4', 'data5'],
        [5, 'data3', 'data2'],
        [6, 'data4', 'data5'],
        [7, 'data1', 'data2'],
        [8, 'data4', 'data5']
    ])

    return {'Facts': f,
            'dimension': d}


def to_dataframe(ndarray,dim_type='dimension'):
    """

    data -> ndarray[1:, 1:]
    index -> ndarray[1:, 0]
    columns -> ndarray[0, 1:]

    :param ndarray: numpy multidimentional array
    :return:
    """

    if dim_type == 'facts':
        column_name = 'measure'
    else:
        column_name = 'column'

    # generate dataframe columns names
    # ['id', 'column0', 'column1'....]
    columns = ['id'] + [column_name +  str(idx) for idx, val in enumerate(ndarray[0, 1:]) ]


    df = pd.DataFrame(data=ndarray,
                      columns=columns)

    # convert id column to integer
    df[['id']] = df[['id']].astype(int)

    return df


def loard_tables():

    ndarrays = mock_big_array()

    facts = to_dataframe(ndarrays['Facts'],dim_type='facts')

    dim = to_dataframe(ndarrays['dimension'])


    # remove id column
    facts = facts[[col for col in facts.columns if col != 'id']]

    # remove id column
    dim = dim[[col for col in dim.columns if col != 'id']]


    return {'Facts' : facts,
            'Dim' : dim}

def merge():

    # todo merge directly from load_tables() above

    ndarrays = mock_big_array()

    dim = to_dataframe(ndarrays['dimension'])

    facts = to_dataframe(ndarrays['Facts'], dim_type='facts')

    df = facts.merge(dim,on='id')

    return df[[col for col in df.columns if col != 'id']]

# AND then use load_tables and merge in olapy's execte module directly

# ligne 152 : load_tables() -> get all dimensions and facts
#
# ligne 207 : get_star_schema_dataframe() -> call the merged dataframe

